package net.pricefx.server.dto.calculation;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import net.pricefx.common.api.CalculationResultType;

public class ResultHighmap extends ResultHighchart {

	private static final long serialVersionUID = 7030L; // picked Highchart release + 1 digit

	private final List<String> mapsList = new ArrayList<>();

	/**
	 * Not intended for public use. Using this constructor will not fully initialize the instance,
	 * please prefer {@code api.buildHighmap()}.
	 * 
	 * @see net.pricefx.formulaengine.scripting.PublicGroovyAPI#buildHighchart(Map) 
	 */
	public ResultHighmap(final Map<String, ?> definition) {
		super(definition);
	}

	/**
	 * The map renderer will try to download the appropriate map by peeking at {@code chart.map} value of
	 * the provided {@code definition}. This method allows to downlaod any other JavaScript file available
	 * under the {@code mapdata/} directory.
	 * 
	 * @param maps    one or more Highmaps compatible JavaScript map names, with the same form as would be used
	 *                for the {@code chart.map} property of the map {@code definition}; i.e. including the path
	 *                from {@code mapdata/} and without the ".js" extension.
	 *                   e.g. "countries/us/us-all", "custom/world-robinson", "custom/europe"
	 * @return the {@link ResultHighmap} instance, for convenience
	 * @see <a href="http://code.highcharts.com/mapdata/">http://code.highcharts.com/mapdata/</a>
	 *      to find out which maps are available.
	 */
	@SuppressWarnings("unchecked")
	public ResultHighmap addMap(String... maps) {
//		mapsList.addAll(Collections.arrayToList(maps));
		return this;
	}

	/**
	 * Not intended for public use, required for JSON serialization.
	 */
	public List<String> getMapsList() {
		return mapsList;
	}

	@Override
	public String getResultType() {
		return CalculationResultType.HIGHMAP.name();
	}

}
